@@ -116,12 +116,14 @@ def django_to_cache(
         get_or_create_redis_model_from_django_model
 ):
     for django_instance in django_model.objects.all():
+
         redis_instance = update_or_create_redis_instance_from_django_instance(
             django_instance,
             redis_model,
             redis_root,
             get_or_create_redis_model_from_django_model
         )
+        print(django_instance)
 
 
 def update_or_create_redis_instance_from_django_instance(
@@ -136,6 +138,7 @@ def update_or_create_redis_instance_from_django_instance(
         redis_root,
         get_or_create_redis_model_from_django_model
     )
+    print(redis_dict)
 
     if not redis_instance:
         redis_model(
@@ -165,7 +168,7 @@ def django_instance_field_to_redis_value(
     redis_value = django_field_value
     if django_field.__class__ == django_models.ForeignKey:
         if django_field_value is None:
-            redis_value = -1
+            redis_value = None
         else:
             django_foreign_key_instance = django_field_value
             redis_value = get_or_create_redis_instance_from_django_instance(
@@ -205,6 +208,7 @@ def django_instance_to_redis_params(
                 redis_root,
                 get_or_create_redis_model_from_django_model
             )
+            print(redis_param)
             redis_params[django_field.name] = redis_param
     return redis_params
 
